body {
  color: #3d3d3d; }

a {
  color: #2f4f4f;
  text-decoration: none; }
  a:hover {
    color: #778899; }

div#container {
  position: relative;
  width: 980px;
  margin: 20px auto; }

header {
  margin: 0 0 50px 0; }
  header h1 {
    font-family: Georgia, sans-serif;
    font-style: normal;
    letter-spacing: 0.1em;
    word-spacing: 0.6em;
    line-height: 1.2em;
    text-align: center; }
    header h1 a {
      color: #3d3d3d; }
  header p {
    font-size: 1.2em;
    font-family: Arial, serif;
    text-align: center;
    color: #6d6d6d; }
  header nav {
    position: absolute;
    top: 0;
    right: 0; }

section#contents {
  border-top: 1px solid #dedede;
  border-bottom: 1px solid #dedede;
  margin: 20px 0; }
  section#contents > h1 {
    display: none; }
  section#contents:after {
    visibility: hidden;
    display: block;
    font-size: 0;
    content: " ";
    clear: both;
    height: 0; }
  section#contents article.entry {
    position: relative;
    float: left;
    width: 460px;
    height: 200px;
    padding: 10px;
    overflow: hidden; }
    section#contents article.entry h1 {
      display: inline-block; }
    section#contents article.entry nav {
      display: inline-block; }
      section#contents article.entry nav ul {
        margin: 0;
        padding: 0; }
        section#contents article.entry nav ul li {
          display: inline-block; }
          section#contents article.entry nav ul li a {
            display: block;
            width: 16px;
            height: 16px;
            text-indent: -10000px; }
          section#contents article.entry nav ul li.entry-update a {
            background: url(image/edit.png) no-repeat; }
          section#contents article.entry nav ul li.entry-delete a {
            background: url(image/trash.png) no-repeat; }
    section#contents article.entry p.subscription {
      font-size: smaller;
      color: #ababab; }
  section#contents article#entry {
    height: auto; }

* html section#content {
  zoom: 1; }

/* IE6 */
*:first-child + html section#content {
  zoom: 1; }

/* IE7 */
footer {
  margin: 30px 0 0 0;
  font-size: 0.9em;
  color: #ababab;
  text-align: center; }
